Deserializer

Struct Deserializer 

pub struct Deserializer<'a> { /* private fields */ }
Deserializes XML documents.

Implementations

Source

impl<'a> Deserializer<'a>

pub fn from_str(input: &'a str) -> Deserializer<'a>

Creates a deserializer for a string.

pub fn from_str_with_config( input: &'a str, config: DeserializerConfig, ) -> Deserializer<'a>

Creates a deserializer for a string with the given configuration.

pub fn from_slice(input: &'a [u8]) -> Deserializer<'a>

Creates a deserializer for UTF-8 encoded bytes.

pub fn from_slice_with_config( input: &'a [u8], config: DeserializerConfig, ) -> Deserializer<'a>

Creates a deserializer for UTF-8 encoded bytes with the given configuration.

pub fn config(&self) -> &DeserializerConfig

Returns the configuration.

pub fn deserialize<T: Deserialize<'a>>(&mut self) -> Result<T, Error>

Deserializes the document.

pub fn deserialize_with<T, F>(&mut self, setup: F) -> Result<T, Error>
where T: Deserialize<'a>, F: FnOnce(&mut DeserializeDriver<'_, 'a>),

Deserializes the document with a configured driver.

The callback is invoked with the driver before the value is deserialized, for instance to add Layers.

pub fn drive( &mut self, driver: &mut DeserializeDriver<'_, 'a>, ) -> Result<(), Error>

Parses the document and feeds the events into the driver.

Events are emitted while the document is parsed. Text is passed on borrowed from the input unless it has references or line breaks that are normalized.

The context of the configuration is given to the driver (values that the context of the driver has take precedence, see DeserializeDriver::set_default_context).