pub struct DeserializerConfigBuilder { /* private fields */ }Expand description
Builds a DeserializerConfig.
The methods have the names of the setters of DeserializerConfig (without set_).
Implementations
Sourceimpl DeserializerConfigBuilder
impl DeserializerConfigBuilder
Sourcepub const fn new() -> DeserializerConfigBuilder
pub const fn new() -> DeserializerConfigBuilder
Creates a builder that starts with the default.
Sourcepub const fn attribute_prefix(
self,
prefix: &'static str,
) -> DeserializerConfigBuilder
pub const fn attribute_prefix( self, prefix: &'static str, ) -> DeserializerConfigBuilder
Sets the prefix of the keys of attributes.
Sourcepub const fn text_key(self, key: &'static str) -> DeserializerConfigBuilder
pub const fn text_key(self, key: &'static str) -> DeserializerConfigBuilder
Sets the key of the text of elements that are maps.
Sourcepub const fn resolve_namespaces(self, yes: bool) -> DeserializerConfigBuilder
pub const fn resolve_namespaces(self, yes: bool) -> DeserializerConfigBuilder
Enables or disables resolving namespaces.
Sourcepub fn context(self, context: Context) -> DeserializerConfigBuilder
pub fn context(self, context: Context) -> DeserializerConfigBuilder
Sets the context the values are deserialized in.
Sourcepub const fn build(self) -> DeserializerConfig
pub const fn build(self) -> DeserializerConfig
Returns the built DeserializerConfig.