StreamDeserializer

Struct StreamDeserializer 

pub struct StreamDeserializer { /* private fields */ }
Reads an XML document from a stream (see deser::stream).

The stream is a single document which is parsed once the whole stream was read (what follows the root element can only be checked at the end). Like with from_slice the input has to be UTF-8.

use deser_xml::DeserializerConfig;

#[derive(deser::Deserialize)]
struct Link {
    #[deser(rename = "@href")]
    href: String,
}

let mut reader =
    DeserializerConfig::new().reader(&br#"<a href="/x"/>"#[..]);
let link: Link = reader.read().unwrap().unwrap();
assert_eq!(link.href, "/x");
assert!(reader.read::<Link>().unwrap().is_none());

Implementations

Source

impl StreamDeserializer

pub fn new() -> StreamDeserializer

Creates a stream deserializer.

pub fn with_config(config: DeserializerConfig) -> StreamDeserializer

Creates a stream deserializer with the given configuration.

pub fn config(&self) -> &DeserializerConfig

Returns the configuration.