pub struct Serializer { /* private fields */ }Expand description
Serializes values to XML.
This is the XML implementation of the Serializer
trait, which allows serializing to XML where the format is not known
upfront. For a value that is serialized once
SerializerConfig::to_string (or to_string) is simpler.
An XML document has a single root element, serializing a second value
fails. Values without a name (like maps) need a Root
or the name of the root element in the configuration (see
SerializerConfig::set_root).
use std::collections::BTreeMap;
use deser_xml::{Serializer, SerializerConfig};
let mut serializer = Serializer::with_config(SerializerConfig::builder().root("r").build());
serializer.serialize(&BTreeMap::from([("@a", 1), ("b", 2)])).unwrap();
assert!(serializer.serialize(&BTreeMap::from([("b", 3)])).is_err());
assert_eq!(serializer.finish(), r#"<r a="1"><b>2</b></r>"#);The serializer is also the stream serializer of XML (see
StreamSerializer): the output can be taken
while the document is written, and large documents can be written in
parts. Output is final once the start tag it’s in is complete: the
start tag of an element is held back until no more attributes can come,
which for maps (whose keys are not known upfront) is the end of the
element. The namespaces that are found once the start tag of the root
element was written are declared on the elements that use them rather
than on the root element (configured
namespaces are always declared on the
root element). To write to a Write use
SerializerConfig::writer.
Implementations
Sourceimpl Serializer
impl Serializer
Sourcepub fn new() -> Serializer
pub fn new() -> Serializer
Creates a serializer.
Sourcepub fn with_config(config: SerializerConfig) -> Serializer
pub fn with_config(config: SerializerConfig) -> Serializer
Creates a serializer with the given configuration.
Sourcepub fn config(&self) -> &SerializerConfig
pub fn config(&self) -> &SerializerConfig
Returns the configuration.
Sourcepub fn serialize<T: Serialize + ?Sized>(
&mut self,
value: &T,
) -> Result<(), Error>
pub fn serialize<T: Serialize + ?Sized>( &mut self, value: &T, ) -> Result<(), Error>
Serializes a value.
If the value fails to serialize, nothing is written.